# Example 3.10 of Mehttalo, L. and Lappi, J. 2020. Biometry for forestry and environmental data: With examples in R. CRC Press, 
# 
# Author: Lauri Mehttalo
###############################################################################
x<-c(9.76,9.08,16.23,10.28,10.51)
lb<-7; ub<-13 # bounds of the uniform prior

postProfile<-function(theta) {
	sapply(theta, function(thet) prod(dnorm(x,thet,2))*dunif(thet,lb,ub))
}

# The Metropolis algorithm
# Use standard normal density as the proposal distribution
# Start from a random number from the prior
theta<-runif(1,lb,ub)
M<-1; nsim<-1000
thetasim<-rep(NA,nsim)
while (M<=nsim) {
	thetanew<-theta+rnorm(1) # Generate a proposal
	while (thetanew<lb|thetanew>ub) thetanew<-theta+rnorm(1)
	alpha<-postProfile(thetanew)/postProfile(theta)
	if (alpha>1|runif(1)<alpha) {
       theta<-thetasim[M]<-thetanew
	   M<-M+1
	}	
}

## Illustrate the true posterior density pi(theta)f(x|theta)/m(x) on the simulated sample
thetavec<-seq(0,20,0.01)
postden<-postProfile(thetavec)/integrate(postProfile,lb,ub)$value

windows(width=7,height=3)
par(mfcol=c(1,2),mai=c(0.6,0.6,0.1,0.1),mgp=c(2,0.7,0),cex=0.9)
plot(thetasim,type="l",xlab="M",ylab=expression(theta))
hist(thetasim,freq=FALSE,xlab=expression(theta),ylab="Posteriotr density",main="",ylim=c(-0.1,0.5))
lines(thetavec,postden)
points(mean(thetasim),-0.05,pch=3)
lines(rep(quantile(thetasim,c(0.025,0.975)),each=4),rep(c(-0.05,-0.04,-0.06,-0.05),2))
text(quantile(thetasim,c(0.025,0.5,0.975)),rep(-0.08,3),c("lb","post. mean","ub"))

## Compute the point estimate and the 95% credible interval
# Using the MCMC sample
mean(thetasim)
quantile(thetasim,probs=c(0.025,0.975))

# Using sample mean, its known standard error and normal distirution
mean(x)
qnorm(c(0.025,0.975),mean(x),2/sqrt(length(x)))





