# Example 3.3 of Mehttalo, L. and Lappi, J. 2020. Biometry for forestry and environmental data: With examples in R. CRC Press, 
# 
# Author: Lauri Mehttalo
###############################################################################
data<-c(6,5,4)

s1<-1.5^2
s2<-1.2^2

Sigma<-matrix(c(s1+s2,s1,   0,
              s1,   s1+s2,0,
              0,0,s1+s2),ncol=3)
sqrt(diag(Sigma))
cov2cor(Sigma)

library(mnormt)

nll<-function(mu) -log(dmnorm(data, mean = rep(mu,3), varcov=Sigma))

library(stats4)
sol<-mle(nll,start=list(mu=mean(data)))

library(stats4)
y10<-c(4.99, 4.42, 5.95, 4.49, 5.75, 3.92, 7.74, 5.77, 4.75, 5.61)
y20<-c(5.80, 6.00, 5.35, 3.98, 4.99, 5.34, 5.14, 5.36, 3.19, 4.62, 
		4.57, 3.23, 5.57, 4.18, 4.66, 6.76, 5.83, 4.74, 6.91, 4.44)


# mll needs negative likelihood
nll10<-function(mu) -sum(log(dnorm(y10,mu)))
nll20<-function(mu) -sum(log(dnorm(y20,mu)))

sol10<-mle(minuslogl=nll10,start=list(mu=0))
sol20<-mle(minuslogl=nll20,start=list(mu=0))

summary(sol10)
mean(y10)
sqrt(1/10)

windows(width=7, height=3)
par(mfcol=c(1,2),mai=c(0.6, 0.6, 0.1, 0.1),mgp=c(2, 0.7, 0),cex=0.9)
x<-seq(4,6,0.1)
ll<--sapply(x,nll)
plot(x,ll,type="l",xlab=expression(mu),ylab=expression(ll(mu)))
abline(v=coef(sol))

mu<-seq(0,10,0.1)
plot(mu,-sapply(mu,function(x) nll10(x)),type="l",
		xlab=expression(mu),ylab=expression(ll(mu)),lwd=2,ylim=c(-160,0))
lines(mu,-sapply(mu,function(x) nll20(x)),type="l",lty="dashed",lwd=2)

abline(v=coef(sol10))
abline(v=coef(sol20))
legend("topleft",lwd=c(2,2),lty=c("solid","dashed"),legend=c("n=10","n=20"))