# Example 3.9 of Mehttalo, L. and Lappi, J. 2020. Biometry for forestry and environmental data: With examples in R. CRC Press, 
# 
# Author: Lauri Mehttalo
###############################################################################

library(stats4)

v<-c(1,4,5,11,16,18,19,20,22,23,23,24,26,27,27,28,29,29,30,30,31,32,33,46,48,
     50,51,51,53,54,55,61,62,62,62,64,65,67,68,69,76,77,81,81,83,84,86,91,92,99)

set.seed(1234)
obs<-rpois(length(v),exp(-2+0.05*v))
obs

# We use log link to ensure positive $\lambda$
# We assume that lambda=exp(b0+b1*x)
nll<-function(b0,b1) {
     value<--sum(log(dpois(obs,exp(b0+b1*v))),na.rm=TRUE)
#	 cat(value,"\n")
#	 value
}

solution<-mle(minuslogl=nll,start=list(b0=0.5,b1=0),control=list(trace=TRUE))
beta<-coef(solution)
beta
vcov(solution)

windows()
plot(v,obs,xlab=expression("v, "*m^3/ha),ylab="Number of insects")
v0<-seq(0,100,1)
lines(v0,exp(beta[1]+beta[2]*v0))
lines(v0,exp(-2+0.05*v0),lty="dashed")
legend(x="topleft",legend=c(expression("True:      "*mu[i]==exp(-2.00+0.050*v[i])),
				            expression("Estimated: "*mu[i]==exp(-2.25+0.053*v[i]))),lty=c("dashed","solid"))
